diff src/share/vm/runtime/thread.hpp @ 2891:75a99b4f1c98

Rebranded C++ part from C1X to Graal.
author Thomas Wuerthinger <thomas@wuerthinger.net>
date Wed, 08 Jun 2011 14:01:51 +0200
parents 0cd39a385a72
children be4ca325525a
line wrap: on
line diff
--- a/src/share/vm/runtime/thread.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/runtime/thread.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -833,8 +833,8 @@
 
  private:
 
-  // c1x needs some place to put the dimensions
-  jint c1x_multinewarray_storage[256];
+  // graal needs some place to put the dimensions
+  jint graal_multinewarray_storage[256];
 
   StackGuardState        _stack_guard_state;
 
@@ -1271,7 +1271,7 @@
   static ByteSize is_method_handle_return_offset() { return byte_offset_of(JavaThread, _is_method_handle_return); }
   static ByteSize stack_guard_state_offset()     { return byte_offset_of(JavaThread, _stack_guard_state   ); }
   static ByteSize suspend_flags_offset()         { return byte_offset_of(JavaThread, _suspend_flags       ); }
-  static ByteSize c1x_multinewarray_storage_offset() { return byte_offset_of(JavaThread, c1x_multinewarray_storage); }
+  static ByteSize graal_multinewarray_storage_offset() { return byte_offset_of(JavaThread, graal_multinewarray_storage); }
 
   static ByteSize do_not_unlock_if_synchronized_offset() { return byte_offset_of(JavaThread, _do_not_unlock_if_synchronized); }
   static ByteSize should_post_on_exceptions_flag_offset() {